/*
 Disclaimer: IMPORTANT:  This INVASIVECODE software is supplied to you by INVASIVECODE
 Inc. ("INVASIVECODE") in consideration of your agreement to the following
 terms, and your use, installation, modification or redistribution of
 this INVASIVECODE software constitutes acceptance of these terms.  If you do
 not agree with these terms, please do not use, install, modify or
 redistribute this INVASIVECODE software.
 
 In consideration of your agreement to abide by the following terms, and
 subject to these terms, INVASIVECODE grants you a personal, non-exclusive
 license, under INVASIVECODE's copyrights in this original INVASIVECODE software (the
 "INVASIVECODE Software"), to use, reproduce, modify and redistribute the INVASIVECODE
 Software, with or without modifications, in source and/or binary forms;
 provided that if you redistribute the INVASIVECODE Software in its entirety and
 without modifications, you must retain this notice and the following
 text and disclaimers in all such redistributions of the INVASIVECODE Software.
 Neither the name, trademarks, service marks or logos of INVASIVECODE Inc. may
 be used to endorse or promote products derived from the INVASIVECODE Software
 without specific prior written permission from INVASIVECODE. Except as
 expressly stated in this notice, no other rights or licenses, express or
 implied, are granted by INVASIVECODE herein, including but not limited to any
 patent rights that may be infringed by your derivative works or by other
 works in which the INVASIVECODE Software may be incorporated.
 
 The INVASIVECODE Software is provided by INVASIVECODE on an "AS IS" basis. INVASIVECODE
 MAKES NO WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION
 THE IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS
 FOR A PARTICULAR PURPOSE, REGARDING THE INVASIVECODE SOFTWARE OR ITS USE AND
 OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
 
 IN NO EVENT SHALL INVASIVECODE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL
 OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE, REPRODUCTION,
 MODIFICATION AND/OR DISTRIBUTION OF THE INVASIVECODE SOFTWARE, HOWEVER CAUSED
 AND WHETHER UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE),
 STRICT LIABILITY OR OTHERWISE, EVEN IF INVASIVECODE HAS BEEN ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.
 
 Copyright (C) 2016 INVASIVECODE Inc. All Rights Reserved.*/

#import "ViewController.h"
@import SignaKit;

@interface ViewController () <ISKSignaKitViewControllerDelegate>

@property (nullable, nonatomic, strong) NSArray *documents;
@property (strong, nonatomic) UIBarButtonItem *shareBarButtonItem;
@property (nonatomic, strong, nullable) NSURL *lastSignedDocument;

@end

@implementation ViewController

- (void)viewDidLoad {
	[super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
	self.title = NSLocalizedString(@"Documents", @"Navigation Bar Title");
	
	self.documents = @[@"NetServices", @"NetworkingOverview", @"Streams", @"Certificate", @"Letter"];
	
	self.shareBarButtonItem = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemAction target:self action:@selector(shareAction:)];
	self.navigationItem.rightBarButtonItem = self.shareBarButtonItem;
	self.shareBarButtonItem.enabled = NO;
	
	self.lastSignedDocument = nil;
}

- (void)shareAction:(id)sender
{
	NSData *documentData = [NSData dataWithContentsOfURL:self.lastSignedDocument];
	
	if (documentData) {
		NSArray *activityItems = @[documentData];
		
		UIActivityViewController *viewController = [[UIActivityViewController alloc] initWithActivityItems:activityItems applicationActivities:nil];
		
		if ([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPad) {
			viewController.modalPresentationStyle = UIModalPresentationPopover;
			[self presentViewController:viewController animated:YES completion:nil];
			
			UIPopoverPresentationController *presentationController = viewController.popoverPresentationController;
			presentationController.permittedArrowDirections = UIPopoverArrowDirectionUp;
			presentationController.barButtonItem = self.shareBarButtonItem;
			
		} else {
			[self presentViewController:viewController animated:YES completion:nil];
		}
	}
}

#pragma mark - Table View

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
	return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
	return self.documents.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
	UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"Cell" forIndexPath:indexPath];
	
	cell.textLabel.text = self.documents[indexPath.row];
	return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
	NSURL *documentURL = [[NSBundle mainBundle] URLForResource:self.documents[indexPath.row] withExtension:@"pdf"];
	ISKSignaKitViewController *viewController = [[ISKSignaKitViewController alloc] initWithPDFDocument:documentURL];
	viewController.delegate = self;
	[self presentViewController:viewController animated:YES completion:nil];
}

#pragma mark - ICKSignatureViewControllerDelegate
- (void)signaKitViewController:(ISKSignaKitViewController *)signaKitViewController didSignPDFDocumentAtURL:(NSURL *)documentURL
{
	self.lastSignedDocument = documentURL;
	if (documentURL != nil) {
		self.shareBarButtonItem.enabled = YES;
	} else {
		self.shareBarButtonItem.enabled = NO;
	}
	[self dismissViewControllerAnimated:YES completion:nil];
}

- (void)signaKitViewControllerDidCancel:(ISKSignaKitViewController *)signaKitViewController
{
	[self dismissViewControllerAnimated:YES completion:nil];
}

@end
